@@ -272,6 +272,30 @@ class BlockchainAPIResource(APIResource):
             BlockchainNetwork.SolanaNetwork,
         ] = network
 
+    def get_rpc_url(
+        self
+    ) -> str:
+        return f"{self._url}/{self.blockchain.value}/{self.network.value}/rpc"
+
+    def make_rpc_request(
+        self,
+        method: str,
+        params: object
+    ) -> str:
+        response = self._request(
+            endpoint=self.get_rpc_url(),
+            payload={
+                'method': method,
+                'params': params
+            },
+            request_method=self._RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    # -------------------------------------------------------------------------------------------- BEGIN: WALLET
+
     def generate_seed_phrase(
         self
     ) -> str:
@@ -447,6 +471,10 @@ class BlockchainAPIResource(APIResource):
             raise Exception(response['error_message'])
         return response['transaction_blockchain_identifier']
 
+    # -------------------------------------------------------------------------------------------- END: WALLET
+
+    # -------------------------------------------------------------------------------------------- BEGIN: TRANSACTION
+
     def get_transaction(
         self,
         transaction_blockchain_identifier: str
@@ -465,3 +493,68 @@ class BlockchainAPIResource(APIResource):
         if 'error_message' in response:
             raise Exception(response['error_message'])
         return response
+
+    # -------------------------------------------------------------------------------------------- END: TRANSACTION
+
+    # -------------------------------------------------------------------------------------------- BEGIN: NAME SERVICE
+
+    def get_name_from_blockchain_identifier(self, token_blockchain_identifier: str):
+        url = f"{self.blockchain.value}/" \
+              f"{self.network.value}/" \
+              f"name_service/blockchain_identifier_to_name"
+        response = self._request(
+            endpoint=url,
+            payload={
+                'blockchain_identifier': token_blockchain_identifier
+            },
+            request_method=self._RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response['name']
+
+    def get_blockchain_identifier_from_name(self, name: str):
+        url = f"{self.blockchain.value}/" \
+              f"{self.network.value}/" \
+              f"name_service/name_to_blockchain_identifier"
+        response = self._request(
+            endpoint=url,
+            payload={
+                'name': name
+            },
+            request_method=self._RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response['blockchain_identifier']
+
+    # -------------------------------------------------------------------------------------------- END: NAME SERVICE
+
+    # -------------------------------------------------------------------------------------------- BEGIN: TOKENS
+
+    def get_all_tokens(self):
+        url = f"{self.blockchain.value}/" \
+              f"{self.network.value}/" \
+              f"all_tokens"
+        response = self._request(
+            endpoint=url,
+            request_method=self._RequestMethod.GET
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    def get_token_metadata(self, token_blockchain_identifier: str):
+        url = f"{self.blockchain.value}/" \
+              f"{self.network.value}/" \
+              f"token/" \
+              f"{token_blockchain_identifier}"
+        response = self._request(
+            endpoint=url,
+            request_method=self._RequestMethod.GET
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response
+
+    # -------------------------------------------------------------------------------------------- END: WALLET
