@@ -127,8 +127,7 @@ class SolanaWallet:
 
 class APIResource:
 
-    # _url = "https://api.blockchainapi.com/v1/"
-    _url = "http://0.0.0.0:8080/v1/"
+    _url = "https://api.blockchainapi.com/v1/"
     __timeout = 120
 
     class _RequestMethod(Enum):
